summaryrefslogtreecommitdiff
path: root/gdb/defs.h
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2001-01-31 03:46:23 +0000
committerAndrew Cagney <cagney@redhat.com>2001-01-31 03:46:23 +0000
commit0da91883e6d0f516af2278636d276b3de7b46c31 (patch)
treedff36499755b8e7b422cc1e20c3e94135928f736 /gdb/defs.h
parentcc143fd1ce98397ea10059aa97764d8f7ffccc80 (diff)
downloadgdb-0da91883e6d0f516af2278636d276b3de7b46c31.tar.gz
Move putchar_filtered() to utils.c.
Diffstat (limited to 'gdb/defs.h')
-rw-r--r--gdb/defs.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/gdb/defs.h b/gdb/defs.h
index b0612808c03..092f21c5a85 100644
--- a/gdb/defs.h
+++ b/gdb/defs.h
@@ -435,7 +435,8 @@ extern struct ui_file *gdb_stdtarg;
#include "ui-file.h"
-/* More generic printf like operations */
+/* More generic printf like operations. Filtered versions may return
+ non-locally on error. */
extern void fputs_filtered (const char *, struct ui_file *);
@@ -445,6 +446,8 @@ extern int fputc_filtered (int c, struct ui_file *);
extern int fputc_unfiltered (int c, struct ui_file *);
+extern int putchar_filtered (int c);
+
extern int putchar_unfiltered (int c);
extern void puts_filtered (const char *);